@@ -220,12 +220,23 @@ class IQOption:
         timestamp = self.iq.get_server_timestamp()
         timeframe = self.timeframe_to_seconds(timeframe)
         
-
-       
         x = self.iq.get_candles(symbol, int(timeframe), candles, timestamp)
         
+        dataframe = pd.DataFrame(x)
+        dataframe.sort_values(by=["from"], inplace=True, ascending=True)
+        dataframe.drop(dataframe.tail(1).index, inplace=True)
+        dataframe = dataframe.rename(columns = {'from': 'date', 'min': 'low','max':'high'})
+        dataframe = dataframe.set_index(['date'])
+        dataframe.index = pd.to_datetime(dataframe.index, unit='s')
+        return dataframe[["open", "high", "low","close", "volume"]]
+    
+    def history_by_code(self, symbol_code, timeframe,candles):
+        candles = candles + 1
+        timestamp = self.iq.get_server_timestamp()
+        timeframe = self.timeframe_to_seconds(timeframe)
+        
+        x = self.iq.get_candles_by_code(symbol_code, int(timeframe), candles, timestamp)
         
-
         dataframe = pd.DataFrame(x)
         dataframe.sort_values(by=["from"], inplace=True, ascending=True)
         dataframe.drop(dataframe.tail(1).index, inplace=True)
