@@ -468,6 +468,19 @@ class IQ_Option:
             raise e
 
         return self.api.candles.candles_data
+    
+    def get_candles_by_code(self, ACTIVE_CODE, interval, count, endtime):
+        self.api.candles.candles_data = None
+        try:
+            self.api.getcandles(ACTIVE_CODE, interval, count, endtime)
+            while self.check_connect:
+                if self.api.candles.candles_data != None:
+                    break
+        except Exception as e:
+            logging.error(e)
+            raise e
+
+        return self.api.candles.candles_data
 
     #######################################################
     # ______________________________________________________
